<?php
/**
 * @file
 * Ensemble Video Chooser admin settings include.
 */

/**
 * Page callback: Ensemble Video Chooser settings.
 *
 * @see ensemble_video_chooser_menu()
 */
function ensemble_video_chooser_admin_settings($form, &$form_state) {
  $form['ensemble_video_chooser_launch_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Launch Url'),
    '#default_value' => variable_get('ensemble_video_chooser_launch_url', ''),
    '#description' => t('LTI Launch Url.'),
    '#required' => TRUE,
  );
  $form['ensemble_video_chooser_consumer_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Consumer Key'),
    '#default_value' => variable_get('ensemble_video_chooser_consumer_key', ''),
    '#description' => t('LTI Consumer Key.'),
    '#required' => TRUE,
  );
  $form['ensemble_video_chooser_shared_secret'] = array(
    '#type' => 'password',
    '#title' => t('Shared Secret'),
    '#default_value' => variable_get('ensemble_video_chooser_shared_secret', ''),
    '#description' => t('LTI Shared Secret.'),
    '#required' => TRUE,
  );
  $form['ensemble_video_chooser_custom_params'] = array(
    '#type' => 'textarea',
    '#title' => t('Additional Parameters'),
    '#default_value' => variable_get('ensemble_video_chooser_custom_params', ''),
    '#description' => t('Additional LTI Parameters.'),
    '#required' => FALSE,
  );
  return system_settings_form($form);
}

/**
 * Handles validation of chooser admin settings.
 */
function ensemble_video_chooser_admin_settings_validate($form, &$form_state) {
  $param_text = $form_state['values']['ensemble_video_chooser_custom_params'];
  $params = explode("\r\n", $param_text);
  $parsed_params = array();
  foreach ($params as $param) {
    $param = trim($param);
    if ($param === '') {
      continue;
    }
    if (!preg_match('/^custom_/', $param)) {
      form_set_error('ensemble_video_chooser_custom_params', t('"@param" must start with "custom_".', array('@param' => $param)));
      return;
    }
    $parts = explode('=', $param);
    if (count($parts) !== 2) {
      form_set_error('ensemble_video_chooser_custom_params', t('"@param" should be in the format "key=value".', array('@param' => $param)));
      return;
    }
    $parts[0] = trim($parts[0]);
    $parts[1] = trim($parts[1]);
    $param = implode('=', $parts);
    $parsed_params[] = $param;
  }
  $form_state['values']['ensemble_video_chooser_custom_params'] = implode("\n", $parsed_params);
}
